@@ -14,7 +14,16 @@ import uuid
 
 from rubpy.bot.enums import ChatKeypadTypeEnum, UpdateTypeEnum
 from rubpy.bot.filters import Filter
-from rubpy.bot.models import Keypad, InlineMessage, Update, Message, MessageId, Chat, Bot
+from rubpy.bot.models import (
+    Keypad,
+    InlineMessage,
+    Update,
+    Message,
+    MessageId,
+    Chat,
+    Bot,
+)
+from rubpy.bot.exceptions import APIException
 
 # Setup logging
 # logging.basicConfig(level=logging.ERROR)
@@ -31,9 +40,19 @@ def has_time_passed(last_time, seconds: int = 5) -> bool:
 
 
 class BotClient:
-    def __init__(self, token: str, rate_limit: float = 0.5, use_webhook: bool = False):
+    BASE_URL = "https://botapi.rubika.ir/v3/{}/"
+
+    def __init__(
+            self,
+            token: str,
+            rate_limit: float = 0.5,
+            use_webhook: bool = False,
+            timeout: Union[int, float] = 10.0,
+            connector: "aiohttp.TCPConnector" = None
+    ) -> None:
+
         self.token = token
-        self.base_url = f"https://botapi.rubika.ir/v3/{token}/"
+        self.base_url = self.BASE_URL.format(token)
         self.handlers: Dict[str, List[Tuple[Tuple[Filter, ...], Callable]]] = {}
         self.session = None
         self.running = False
@@ -43,8 +62,24 @@ class BotClient:
         self.last_request_time = 0
         self.first_get_updates = True
         self.use_webhook = use_webhook
+        self.timeout = timeout
+        self.connector = connector
         logger.info("Rubika client initialized, use_webhook=%s", use_webhook)
 
+    async def __aenter__(self) -> "BotClient":
+        await self.start()
+        return self
+    
+    async def __aexit__(self, exc_type, exc_value, traceback) -> None:
+        await self.stop()
+    
+    def __enter__(self) -> "BotClient":
+        self.start()
+        return self
+    
+    def __exit__(self, exc_type, exc_value, traceback) -> None:
+        self.stop()
+
     async def _rate_limit_delay(self):
         elapsed = time.time() - self.last_request_time
         if elapsed < self.rate_limit:
@@ -53,42 +88,37 @@ class BotClient:
 
     async def start(self):
         if self.session is None or self.session.closed:
-            self.session = aiohttp.ClientSession()
+            timeout = aiohttp.ClientTimeout(total=self.timeout)
+            connector = self.connector or aiohttp.TCPConnector(limit=50, limit_per_host=10)
+            self.session = aiohttp.ClientSession(timeout=timeout, connector=connector)
         self.running = True
-        logger.info("Rubika client started")
+        logger.info("RubikaPY bot client started")
 
     async def stop(self):
         if self.session and not self.session.closed:
             await self.session.close()
         self.running = False
-        logger.info("Rubika client stopped")
+        logger.info("RubikaPY bot client stopped")
 
     async def _make_request(self, method: str, data: Dict) -> Dict:
         await self._rate_limit_delay()
         url = f"{self.base_url}{method}"
-        try:
-            async with self.session.post(url, json=data) as response:
-                if response.status != 200:
-                    text = await response.text()
-                    logger.error(
-                        f"Request failed: {method} status={response.status} body={text}"
-                    )
-                    raise aiohttp.ClientResponseError(
-                        response.request_info,
-                        response.history,
-                        status=response.status,
-                        message=text,
-                    )
-                result = await response.json()
-                logger.debug(f"API response for {method}: {result}")
+        
+        async with self.session.post(url, json=data) as response:
+            if not response.ok:
+                raise
 
-                if result["status"] != "OK":
-                    logger.error(f"API error in {method}: {result}")
-                    raise
-                return result["data"]
-        except Exception as e:
-            logger.error(f"Error in _make_request for {method}: {str(e)}")
-            return {"status": "ERROR", "error": str(e)}
+            result = await response.json()
+            logger.debug(f"API response for {method}: {result}")
+
+            if result["status"] != "OK":
+                print(result)
+                raise APIException(
+                    status=result["status"],
+                    dev_message=result.get("dev_message")
+                )
+            
+            return result["data"]
 
     async def get_me(self) -> Bot:
         result = await self._make_request("getMe", {})
@@ -198,7 +228,6 @@ class BotClient:
             )
 
         result = await self._make_request("requestSendFile", {"type": type})
-        print(result)
         return result["upload_url"]
 
     async def upload_file(self, url: str, file_name: str, file_path: str) -> str:
@@ -219,9 +248,7 @@ class BotClient:
                     )
 
                 data = await res.json()
-                return data["data"][
-                    "file_id"
-                ]  # اطمینان حاصل کن که ساختار JSON این‌طوریه
+                return data["data"]["file_id"]  # اطمینان حاصل کن که ساختار JSON این‌طوریه
 
     async def get_file(self, file_id: str) -> str:
         result = await self._make_request("getFile", {"file_id": file_id})
@@ -301,25 +328,35 @@ class BotClient:
 
     async def get_updates(
         self, limit: int = 100, offset_id: str = ""
-    ) -> List[Union[Update, InlineMessage]]:
-        data = {"limit": limit}
-        updates = []
-        if offset_id:
-            data["offset_id"] = offset_id
+    ) -> List[Update]:
+        """
+        Fetch updates from the server.
+
+        Args:
+            limit (int): Maximum number of updates to fetch.
+            offset_id (str): Offset for pagination.
+
+        Returns:
+            List[Update]: Parsed updates as Update objects.
+        """
+        # ساخت دیتا به صورت مستقیم (کاهش شرط اضافی)
+        data = {"limit": limit, **({"offset_id": offset_id} if offset_id else {})}
+
         response = await self._make_request("getUpdates", data)
+        updates_raw = response.get("updates")
+        if not updates_raw:
+            return []
 
-        if response["updates"]:
-            for update in response["updates"]:
-                chat_id = update.get("chat_id", "")
-                update = Update(
-                    type=update.get("type", ""),
-                    chat_id=chat_id,
-                    client=self,
-                    removed_message_id=str(update.get("removed_message_id", "")),
-                )
-                updates.append(update)
-
-        return updates
+        # ساخت لیست با list comprehension (سریع‌تر از for)
+        return [
+            Update(
+                type=u.get("type", ""),
+                chat_id=u.get("chat_id", ""),
+                client=self,
+                removed_message_id=str(u.get("removed_message_id", "")),
+            )
+            for u in updates_raw
+        ]
 
     async def updater(
         self, limit: int = 100, offset_id: str = ""
@@ -426,6 +463,62 @@ class BotClient:
         return await self._make_request(
             "updateBotEndpoints", {"url": url, "type": endpoint_type}
         )
+    
+    async def get_chat_member(self, chat_id: str, user_id: str):
+        return await self._make_request(
+            "getChatMember", {"chat_id": chat_id, "user_id": user_id}
+        )
+    
+    async def pin_chat_message(self, chat_id: str, message_id: str, disable_notification: Optional[bool] = False):
+        payload = {
+            "chat_id": chat_id,
+            "message_id": message_id,
+            "disable_notification": disable_notification
+        }
+        return await self._make_request("pinChatMessage", payload)
+    
+    async def unpin_chat_message(self, chat_id: str, message_id: str):
+        payload = {
+            "chat_id": chat_id,
+            "message_id": message_id
+        }
+        return await self._make_request("unpinChatMessage", payload)
+    
+    async def unpin_all_chat_messages(self, chat_id: str, message_id: str):
+        payload = {
+            "chat_id": chat_id,
+            "message_id": message_id
+        }
+        return await self._make_request("unpinAllChatMessages", payload)
+
+    async def get_chat_administrators(self, chat_id: str):
+        return await self._make_request("getChatAdministrators", {"chat_id": chat_id})
+
+    async def get_chat_member_count(self, chat_id: str):
+        return await self._make_request("getChatMemberCount", {"chat_id": chat_id})
+
+    async def ban_chat_member(self, chat_id: str, user_id: str):
+        return await self._make_request(
+            "banChatMember", {"chat_id": chat_id, "user_id": user_id}
+        )
+
+    async def unban_chat_member(self, chat_id: str, user_id: str):
+        return await self._make_request(
+            "unbanChatMember", {"chat_id": chat_id, "user_id": user_id}
+        )
+
+    async def get_chat_member(self, chat_id: str, user_id: str):
+        return await self._make_request(
+            "getChatMember", {"chat_id": chat_id, "user_id": user_id}
+        )
+
+    async def promote_chat_member(self, chat_id: str, user_id: str):
+        raise NotImplementedError
+
+    async def set_chat_permissions(
+        self, chat_id: str, permissions: Optional[list] = None
+    ):
+        raise NotImplementedError
 
     async def edit_chat_keypad(
         self,
@@ -571,6 +664,7 @@ class BotClient:
                                 ),
                             ).start()
                         handled = True
+                        return
                     except Exception as e:
                         logger.exception(
                             f"Error in handler {handler.__name__}: {str(e)}"
@@ -685,12 +779,13 @@ class BotClient:
             webhook_base = path.rstrip("/")
             app.router.add_post(f"{webhook_base}", self.handle_webhook)
             app.router.add_post(f"{webhook_base}/receiveUpdate", self.handle_webhook)
-            app.router.add_post(
-                f"{webhook_base}/receiveInlineMessage", self.handle_webhook
-            )
+            app.router.add_post(f"{webhook_base}/receiveInlineMessage", self.handle_webhook)
+            app.router.add_post(f"{webhook_base}/receiveQuery", self.handle_webhook)
+            app.router.add_post(f"{webhook_base}/getSelectionItem", self.handle_webhook)
+            app.router.add_post(f"{webhook_base}/searchSelectionItems", self.handle_webhook)
 
             webhook_url = f"{webhook_url.rstrip('/')}{webhook_base}"
-            for endpoint_type in ["ReceiveUpdate", "ReceiveInlineMessage"]:
+            for endpoint_type in ["ReceiveUpdate", "ReceiveInlineMessage", "ReceiveQuery", "GetSelectionItem", "SearchSelectionItems"]:
                 response = await self.update_bot_endpoints(webhook_url, endpoint_type)
                 logger.info(
                     f"Webhook set for {endpoint_type} to {webhook_url}: {response}"
@@ -713,10 +808,8 @@ class BotClient:
                     for update in updates:
                         logger.info(f"Processing polled update: {update}")
                         asyncio.create_task(self.process_update(update))
-                    await asyncio.sleep(0.1)
                 except Exception as e:
                     logger.error(f"Polling error: {str(e)}")
-                    await asyncio.sleep(2)
 
     async def close(self):
         if not self.session.closed:
