@@ -1,6 +1,7 @@
 # Filters
+import asyncio
 import re
-from typing import List, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 from rubpy.bot.models import Update
 from rubpy.bot.models import InlineMessage
@@ -10,6 +11,7 @@ class Filter:
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         return True
 
+
 class text(Filter):
     """
     Filter for checking message text content.
@@ -53,13 +55,14 @@ class text(Filter):
         self.regex = regex
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
-        text = update.find_key('text')
+        text = update.find_key("text")
         if not text:
             return False
         if not self.text and not self.regex:
             return True
         return bool(re.match(self.text, text)) if self.regex else text == self.text
 
+
 class commands(Filter):
     """
     Filter for detecting command messages (e.g. /start, /help).
@@ -95,14 +98,13 @@ class commands(Filter):
         text = (
             update.new_message.text
             if isinstance(update, Update) and update.new_message
-            else update.text
-            if isinstance(update, InlineMessage)
-            else ""
+            else update.text if isinstance(update, InlineMessage) else ""
         )
         if not text:
             return False
         return any(text.startswith(f"/{cmd}") for cmd in self.commands)
 
+
 class update_type(Filter):
     """
     Filter for matching specific update types.
@@ -135,16 +137,18 @@ class update_type(Filter):
     """
 
     def __init__(self, update_types: Union[str, List[str]]):
-        self.update_types = [update_types] if isinstance(update_types, str) else update_types
+        self.update_types = (
+            [update_types] if isinstance(update_types, str) else update_types
+        )
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
-        result = (
-            (isinstance(update, Update) and update.type in self.update_types)
-            or (isinstance(update, InlineMessage) and "InlineMessage" in self.update_types)
+        result = (isinstance(update, Update) and update.type in self.update_types) or (
+            isinstance(update, InlineMessage) and "InlineMessage" in self.update_types
         )
         # logger.info(f"UpdateTypeFilter check for types={self.update_types}, update={type(update).__name__}: {result}")
         return result
-    
+
+
 class private(Filter):
     """
     Filter for detecting messages sent in private (one-on-one) chats.
@@ -159,16 +163,17 @@ class private(Filter):
         >>> from rubpy import BotClient
         >>> from rubpy.bot.models import Update
         >>> from rubpy.bot.filters import private
-        >>> 
+        >>>
         >>> bot_client = BotClient("your_bot_token")
-        >>> 
+        >>>
         >>> @bot_client.on_update(private)
         ... async def handle_private_message(c, update):
         ...     await c.send_message(update.chat_id, "You are chatting privately with the bot.")
     """
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
-        return update.new_message.sender_type == 'User'
+        return bool(update.chat_id.startswith("b0"))
+
 
 class group(Filter):
     """
@@ -185,24 +190,17 @@ class group(Filter):
         >>> from rubpy import BotClient
         >>> from rubpy.bot.models import Update
         >>> from rubpy.bot.filters import group
-        >>> 
+        >>>
         >>> bot_client = BotClient("your_bot_token")
-        >>> 
+        >>>
         >>> @bot_client.on_update(group)
         ... async def handle_group_messages(c, update):
         ...     await c.send_message(update.chat_id, "This message came from a group!")
     """
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
-        sender_type = (
-            update.new_message.sender_type
-            if isinstance(update, Update) and update.new_message
-            else update.updated_message.sender_type
-            if update.updated_message else ""
-        )
-        if not sender_type:
-            return False
-        return sender_type == 'Group'
+        return bool(update.chat_id.startswith("g0"))
+
 
 class bot(Filter):
     """
@@ -218,9 +216,9 @@ class bot(Filter):
         >>> from rubpy import BotClient
         >>> from rubpy.bot.models import Update
         >>> from rubpy.bot.filters import bot
-        >>> 
+        >>>
         >>> bot_client = BotClient("your_bot_token")
-        >>> 
+        >>>
         >>> @bot_client.on_update(bot)
         ... async def handle_bot_messages(c, update):
         ...     await c.send_message(update.chat_id, "A bot sent this message!")
@@ -230,12 +228,12 @@ class bot(Filter):
         sender_type = (
             update.new_message.sender_type
             if isinstance(update, Update) and update.new_message
-            else update.updated_message.sender_type
-            if update.updated_message else ""
+            else update.updated_message.sender_type if update.updated_message else ""
         )
         if not sender_type:
             return False
-        return sender_type == 'Bot'
+        return sender_type == "Bot"
+
 
 class chat(Filter):
     """
@@ -251,13 +249,13 @@ class chat(Filter):
         >>> from rubpy import BotClient
         >>> from rubpy.bot.models import Update
         >>> from rubpy.bot.filters import chat
-        >>> 
+        >>>
         >>> bot = BotClient("your_bot_token")
-        >>> 
+        >>>
         >>> @bot.on_update(chat("b0_test_chat"))
         ... async def only_for_test_chat(c, update):
         ...     await c.send_message(update.chat_id, "Hello from test chat!")
-        >>> 
+        >>>
         >>> @bot.on_update(chat(["b0_admin", "b0_mod"]))
         ... async def for_admins_and_mods(c, update):
         ...     await c.send_message(update.chat_id, "Hello admins and moderators!")
@@ -269,6 +267,7 @@ class chat(Filter):
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         return update.chat_id in self.chats
 
+
 class button(Filter):
     """
     Filter for button click interactions. Supports both direct string comparison and regex matching.
@@ -284,13 +283,13 @@ class button(Filter):
         >>> from rubpy import BotClient
         >>> from rubpy.bot.models import Update
         >>> from rubpy.bot.filters import button
-        >>> 
+        >>>
         >>> bot = BotClient("your_bot_token")
-        >>> 
+        >>>
         >>> @bot.on_update(button("btn_123"))
         ... async def handle_btn(c, update):
         ...     await c.send_message(update.chat_id, "Button 123 clicked!")
-        >>> 
+        >>>
         >>> @bot.on_update(button(r"btn_\\d+", regex=True))
         ... async def handle_regex_btn(c, update):
         ...     await c.send_message(update.chat_id, "Numbered button clicked!")
@@ -332,6 +331,7 @@ class button(Filter):
         else:
             return button_id == self.button_id
 
+
 class forward(Filter):
     """
     Filter for checking forwarded messages.
@@ -353,13 +353,14 @@ class forward(Filter):
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         try:
-            if bool(update.find_key('forwarded_no_link')):
+            if bool(update.find_key("forwarded_no_link")):
                 return True
-            return bool(update.find_key('forwarded_from'))
-        
+            return bool(update.find_key("forwarded_from"))
+
         except KeyError:
             return False
 
+
 class is_edited(Filter):
     """
     Filter for checking edited messages.
@@ -381,11 +382,12 @@ class is_edited(Filter):
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         try:
-            return bool(update.find_key('is_edited'))
+            return bool(update.find_key("is_edited"))
 
         except KeyError:
             return False
 
+
 class sender_type(Filter):
     """
     Filter for matching specific sender types.
@@ -412,17 +414,18 @@ class sender_type(Filter):
         ... async def handle_bots_or_channels(c, update):
         ...     await c.send_message(update.chat_id, "Hello bot or channel!")
     """
-    
+
     def __init__(self, types: Union[List[str], str]):
         self.types = [types] if isinstance(types, str) else types
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         try:
-            sender_type = update.find_key('sender_type')
+            sender_type = update.find_key("sender_type")
             return bool(sender_type in self.types)
         except KeyError:
             return False
 
+
 class has_aux_data(Filter):
     """
     Filter for checking aux_data messages.
@@ -444,11 +447,12 @@ class has_aux_data(Filter):
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         try:
-            return bool(update.find_key('aux_data'))
+            return bool(update.find_key("aux_data"))
 
         except KeyError:
             return False
 
+
 class file(Filter):
     """
     Filter for checking file messages.
@@ -470,11 +474,12 @@ class file(Filter):
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         try:
-            return bool(update.find_key('file'))
+            return bool(update.find_key("file"))
 
         except KeyError:
             return False
 
+
 class location(Filter):
     """
     Filter for checking location messages.
@@ -496,11 +501,12 @@ class location(Filter):
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         try:
-            return bool(update.find_key('location'))
+            return bool(update.find_key("location"))
 
         except KeyError:
             return False
 
+
 class sticker(Filter):
     """
     Filter for checking sticker messages.
@@ -522,11 +528,12 @@ class sticker(Filter):
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         try:
-            return bool(update.find_key('sticker'))
+            return bool(update.find_key("sticker"))
 
         except KeyError:
             return False
 
+
 class contact_message(Filter):
     """
     Filter for checking contact_message messages.
@@ -548,11 +555,12 @@ class contact_message(Filter):
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         try:
-            return bool(update.find_key('contact_message'))
+            return bool(update.find_key("contact_message"))
 
         except KeyError:
             return False
 
+
 class poll(Filter):
     """
     Filter for checking poll messages.
@@ -574,11 +582,12 @@ class poll(Filter):
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         try:
-            return bool(update.find_key('poll'))
+            return bool(update.find_key("poll"))
 
         except KeyError:
             return False
 
+
 class live_location(Filter):
     """
     Filter for checking live_location messages.
@@ -600,7 +609,228 @@ class live_location(Filter):
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         try:
-            return bool(update.find_key('live_location'))
+            return bool(update.find_key("live_location"))
 
         except KeyError:
-            return False
\ No newline at end of file
+            return False
+
+class states(Filter):
+    """
+    Self-contained states filter that stores states in-memory (no external libs).
+    
+    - Use as a filter instance: `s = states("awaiting_email"); @bot.on_update(s) ...`
+    - Also exposes methods to set/get/clear state for a given update:
+        await s.set_state_for(update, "awaiting_email", expire=300)
+        await s.get_state_for(update)
+        await s.clear_state_for(update)
+    
+    Args:
+        targets: None|str|List[str] - states to match (None => match any existing state).
+        match_mode: "exact"|"regex"|"contains"|"any" (default "exact")
+        scope: "user"|"chat"|"both" - where to look up the state keys in internal store
+        check_keys: list of keys to check inside update payload before checking internal store
+        auto_clear: bool - if True and matched => automatically clear stored state
+        set_on_match: Optional[str] - if provided, set this new state on match
+        expire: Optional[int] - default TTL (seconds) when using set_on_match (or when set_state_for uses expire)
+        invert: bool - invert the match result
+    """
+
+    # in-memory stores shared between instances (module-level)
+    _STORE: Dict[str, str] = {}
+    _TTL_TASKS: Dict[str, asyncio.Task] = {}
+
+    def __init__(
+        self,
+        targets: Optional[Union[str, List[str]]] = None,
+        match_mode: str = "exact",
+        scope: str = "user",
+        check_keys: Optional[List[str]] = None,
+        auto_clear: bool = False,
+        set_on_match: Optional[str] = None,
+        expire: Optional[int] = None,
+        invert: bool = False,
+    ):
+        # normalize targets
+        self.targets = [targets] if isinstance(targets, str) else (targets or None)
+        assert match_mode in ("exact", "regex", "contains", "any")
+        assert scope in ("user", "chat", "both")
+        self.match_mode = match_mode
+        self.scope = scope
+        self.check_keys = check_keys or ["state", "fsm_state", "user_state", "session_state"]
+        self.auto_clear = auto_clear
+        self.set_on_match = set_on_match
+        self.default_expire = expire
+        self.invert = invert
+
+        if self.match_mode == "regex" and self.targets:
+            self._patterns = [re.compile(p) for p in self.targets]
+        else:
+            self._patterns = None
+
+    # -------------------------
+    # Helper store / TTL logic
+    # -------------------------
+    @classmethod
+    async def _schedule_expiry(cls, key: str, seconds: int):
+        # cancel existing
+        old = cls._TTL_TASKS.get(key)
+        if old and not old.done():
+            old.cancel()
+        async def _job():
+            try:
+                await asyncio.sleep(seconds)
+                cls._STORE.pop(key, None)
+                cls._TTL_TASKS.pop(key, None)
+            except asyncio.CancelledError:
+                return
+        t = asyncio.create_task(_job())
+        cls._TTL_TASKS[key] = t
+
+    @classmethod
+    async def _set_store(cls, key: str, value: str, expire: Optional[int] = None):
+        cls._STORE[key] = value
+        if expire:
+            await cls._schedule_expiry(key, expire)
+
+    @classmethod
+    async def _get_store(cls, key: str) -> Optional[str]:
+        return cls._STORE.get(key)
+
+    @classmethod
+    async def _clear_store(cls, key: str):
+        cls._STORE.pop(key, None)
+        task = cls._TTL_TASKS.pop(key, None)
+        if task and not task.done():
+            task.cancel()
+
+    # -------------------------
+    # Public helper APIs
+    # -------------------------
+    async def set_state_for(self, update: Union[Update, InlineMessage, Any], value: str, expire: Optional[int] = None):
+        """
+        Set a state for the update's scope (user/chat) according to filter.scope.
+        """
+        klist = self._keys_for_update(update)
+        if not klist:
+            raise RuntimeError("Cannot determine key from update to set state")
+        for k in klist:
+            await self._set_store(k, value, expire or self.default_expire)
+
+    async def get_state_for(self, update: Union[Update, InlineMessage, Any]) -> Optional[str]:
+        """Get first available state from storage for the update (according to scope)."""
+        klist = self._keys_for_update(update)
+        if not klist:
+            return None
+        for k in klist:
+            v = await self._get_store(k)
+            if v is not None:
+                return v
+        return None
+
+    async def clear_state_for(self, update: Union[Update, InlineMessage, Any]):
+        """Clear states (all keys derived from update)."""
+        klist = self._keys_for_update(update)
+        if not klist:
+            return
+        for k in klist:
+            await self._clear_store(k)
+
+    # -------------------------
+    # internal helpers
+    # -------------------------
+    def _keys_for_update(self, update: Union[Update, InlineMessage, Any]) -> List[str]:
+        """
+        Build one or two keys to try based on scope and available ids on update.
+        Keys look like "user:{sender_id}" and/or "chat:{chat_id}".
+        """
+        keys = []
+        # try attributes first
+        sender_id = getattr(update, "sender_id", None)
+        chat_id = getattr(update, "chat_id", None)
+        # fallback to find_key if exists
+        try:
+            if not sender_id and hasattr(update, "find_key"):
+                sender_id = update.find_key("sender_id") or update.find_key("from_id") or sender_id
+        except Exception:
+            pass
+        try:
+            if not chat_id and hasattr(update, "find_key"):
+                chat_id = update.find_key("chat_id") or chat_id
+        except Exception:
+            pass
+
+        if self.scope in ("user", "both") and sender_id:
+            keys.append(f"user:{sender_id}")
+        if self.scope in ("chat", "both") and chat_id:
+            keys.append(f"chat:{chat_id}")
+        return keys
+
+    async def _extract_local_state(self, update: Union[Update, InlineMessage, Any]) -> Optional[str]:
+        """
+        Try to read state directly from update payload keys (without using internal store).
+        Returns first found string value or None.
+        """
+        for k in self.check_keys:
+            try:
+                if hasattr(update, "find_key"):
+                    val = update.find_key(k)
+                else:
+                    val = getattr(update, k, None)
+            except Exception:
+                val = None
+            if val:
+                # if it's collection, pick first str
+                if isinstance(val, (list, tuple, set)):
+                    val = next((x for x in val if isinstance(x, str)), None)
+                if isinstance(val, (str, int, float)):
+                    return str(val)
+        # also look inside aux_data if present
+        try:
+            aux = update.find_key("aux_data") if hasattr(update, "find_key") else getattr(update, "aux_data", None)
+            if aux and isinstance(aux, dict):
+                for k in ("state", "fsm_state"):
+                    v = aux.get(k)
+                    if v:
+                        return str(v)
+        except Exception:
+            pass
+        return None
+
+    def _matches(self, value: str) -> bool:
+        if self.match_mode == "any":
+            return True if value else False
+        if self.match_mode == "contains":
+            return any(t in value for t in (self.targets or []))
+        if self.match_mode == "regex" and self._patterns:
+            return any(p.match(value) for p in self._patterns)
+        # exact
+        return value in (self.targets or [])
+
+    # -------------------------
+    # Filter entry point
+    # -------------------------
+    async def check(self, update: Union[Update, InlineMessage, Any]) -> bool:
+        # 1. local payload
+        local = await self._extract_local_state(update)
+        state_val = None
+        if local:
+            state_val = local
+
+        # 2. fallback to internal store
+        if state_val is None:
+            state_val = await self.get_state_for(update)
+
+        matched = False if state_val is None else self._matches(state_val)
+
+        # apply invert
+        matched = (not matched) if self.invert else matched
+
+        # side-effects
+        if matched:
+            # auto clear or set_on_match
+            if self.auto_clear:
+                await self.clear_state_for(update)
+            if self.set_on_match:
+                await self.set_state_for(update, self.set_on_match, expire=self.default_expire)
+
+        return matched
\ No newline at end of file
