@@ -188,6 +188,47 @@ class AuxData(DictLike):
     button_id: Optional[str] = None
 
 
+@dataclass
+class JoinChannelData(DictLike):
+    username: Optional[str] = None
+    ask_join: Optional[bool] = False
+
+    def __post_init__(self):
+        if self.username:
+            self.username = self.username.replace("@", "")
+
+
+@dataclass
+class OpenChatData(DictLike):
+    object_guid: Optional[str] = None
+    object_type: Optional[ChatTypeEnum] = None
+
+
+@dataclass
+class ButtonLink(DictLike):
+    type: Optional[str] = None
+    link_url: Optional[str] = None
+    joinchannel_data: Optional[JoinChannelData] = None
+    open_chat_data: Optional[OpenChatData] = None
+
+    def __post_init__(self):
+        """Automatically normalize specific Rubika links to deep-link format."""
+        if not self.link_url:
+            return
+
+        mappings = {
+            "https://rubika.ir/joing/": "rubika://g.rubika.ir/",
+            "https://rubika.ir/joinc/": "rubika://c.rubika.ir/",
+            "https://rubika.ir/post/": "rubika://p.rubika.ir/",
+        }
+
+        for prefix, deep_prefix in mappings.items():
+            if self.link_url.startswith(prefix):
+                code = self.link_url[len(prefix) :]
+                self.link_url = deep_prefix + code
+                break
+
+
 @dataclass
 class Button(DictLike):
     id: Optional[str] = None
@@ -199,6 +240,7 @@ class Button(DictLike):
     button_string_picker: Optional[ButtonStringPicker] = None
     button_location: Optional[ButtonLocation] = None
     button_textbox: Optional[ButtonTextbox] = None
+    button_link: Optional[ButtonLink] = None
 
 
 @dataclass
@@ -598,7 +640,7 @@ class InlineMessage(DictLike):
             file=file,
             file_id=file_id,
             text=text,
-            type="Image",
+            type="Voice",
             chat_keypad=chat_keypad,
             inline_keypad=inline_keypad,
             disable_notification=disable_notification,
