@@ -25,6 +25,7 @@ from .get_message_share_url import GetMessageShareUrl
 from .get_messages_updates import GetMessagesUpdates
 from .send_sticker import SendSticker
 from .get_message_reactions import GetMessageReactions
+from .get_messages import GetMessages
 
 
 class Messages(
@@ -55,5 +56,6 @@ class Messages(
         GetMessagesUpdates,
         SendSticker,
         GetMessageReactions,
+        GetMessages
 ):
         pass
\ No newline at end of file
