@@ -1,10 +1,11 @@
 import re
 
 # Define regular expressions for patterns
-RUBIKA_LINK_PATTERN = re.compile(r'\brubika\.ir\b')
-GROUP_LINK_PATTERN = re.compile(r'https://rubika\.ir/joing/[A-Z0-9]+')
-CHANNEL_LINK_PATTERN = re.compile(r'https://rubika\.ir/joing/[A-Z0-9]+')
-USERNAME_PATTERN = re.compile(r'@([a-zA-Z0-9_]{4,32})')
+RUBIKA_LINK_PATTERN = re.compile(r"\brubika\.ir\b")
+GROUP_LINK_PATTERN = re.compile(r"https://rubika\.ir/joing/[A-Z0-9]+")
+CHANNEL_LINK_PATTERN = re.compile(r"https://rubika\.ir/joing/[A-Z0-9]+")
+USERNAME_PATTERN = re.compile(r"@([a-zA-Z0-9_]{4,32})")
+
 
 # Functions to check patterns
 def is_rubika_link(string: str) -> bool:
@@ -16,6 +17,7 @@ def is_rubika_link(string: str) -> bool:
     """
     return bool(RUBIKA_LINK_PATTERN.search(string))
 
+
 def is_group_link(string: str) -> bool:
     """
     Check if the given string contains a Rubika group link.
@@ -25,6 +27,7 @@ def is_group_link(string: str) -> bool:
     """
     return bool(GROUP_LINK_PATTERN.search(string))
 
+
 def is_channel_link(string: str) -> bool:
     """
     Check if the given string contains a Rubika channel link.
@@ -34,6 +37,7 @@ def is_channel_link(string: str) -> bool:
     """
     return bool(CHANNEL_LINK_PATTERN.search(string))
 
+
 def is_username(string: str) -> bool:
     """
     Check if the given string contains a Rubika username.
@@ -43,6 +47,7 @@ def is_username(string: str) -> bool:
     """
     return bool(USERNAME_PATTERN.search(string))
 
+
 # Functions to extract matches
 def get_rubika_links(string: str) -> list:
     """
@@ -53,6 +58,7 @@ def get_rubika_links(string: str) -> list:
     """
     return RUBIKA_LINK_PATTERN.findall(string)
 
+
 def get_group_links(string: str) -> list:
     """
     Extract Rubika group links from the given string.
@@ -62,6 +68,7 @@ def get_group_links(string: str) -> list:
     """
     return GROUP_LINK_PATTERN.findall(string)
 
+
 def get_channel_links(string: str) -> list:
     """
     Extract Rubika channel links from the given string.
@@ -71,6 +78,7 @@ def get_channel_links(string: str) -> list:
     """
     return CHANNEL_LINK_PATTERN.findall(string)
 
+
 def get_usernames(string: str) -> list:
     """
     Extract Rubika usernames from the given string.
@@ -80,6 +88,7 @@ def get_usernames(string: str) -> list:
     """
     return USERNAME_PATTERN.findall(string)
 
+
 # Text formatting functions
 def Bold(text: str) -> str:
     """
@@ -88,7 +97,8 @@ def Bold(text: str) -> str:
     :param text: Input text to be formatted.
     :return: Bold formatted text.
     """
-    return f'**{text.strip()}**'
+    return f"**{text.strip()}**"
+
 
 def Italic(text: str) -> str:
     """
@@ -97,7 +107,8 @@ def Italic(text: str) -> str:
     :param text: Input text to be formatted.
     :return: Italic formatted text.
     """
-    return f'_{text.strip()}'
+    return f"_{text.strip()}"
+
 
 def Underline(text: str) -> str:
     """
@@ -106,7 +117,8 @@ def Underline(text: str) -> str:
     :param text: Input text to be formatted.
     :return: Underlined text.
     """
-    return f'--{text.strip()}--'
+    return f"--{text.strip()}--"
+
 
 def Strike(text: str) -> str:
     """
@@ -115,7 +127,8 @@ def Strike(text: str) -> str:
     :param text: Input text to be formatted.
     :return: Text with strike-through.
     """
-    return f'~~{text.strip()}~~'
+    return f"~~{text.strip()}~~"
+
 
 def Spoiler(text: str) -> str:
     """
@@ -124,7 +137,8 @@ def Spoiler(text: str) -> str:
     :param text: Input text to be formatted.
     :return: Spoiler formatted text.
     """
-    return f'||{text.strip()}||'
+    return f"||{text.strip()}||"
+
 
 def Code(text: str) -> str:
     """
@@ -133,7 +147,8 @@ def Code(text: str) -> str:
     :param text: Input text to be formatted.
     :return: Code formatted text.
     """
-    return f'`{text.strip()}`'
+    return f"`{text.strip()}`"
+
 
 def Mention(text: str, object_guid: str) -> str:
     """
@@ -143,7 +158,8 @@ def Mention(text: str, object_guid: str) -> str:
     :param object_guid: GUID of the mentioned object.
     :return: Mention formatted text.
     """
-    return f'[{text.strip()}]({object_guid.strip()})'
+    return f"[{text.strip()}]({object_guid.strip()})"
+
 
 def Hyperlink(text: str, link: str) -> str:
     """
@@ -153,4 +169,4 @@ def Hyperlink(text: str, link: str) -> str:
     :param link: URL for the hyperlink.
     :return: Hyperlink formatted text.
     """
-    return f'[{text.strip()}]({link.strip()})'
+    return f"[{text.strip()}]({link.strip()})"
